==> ckeditor_4.10.0+dfsg.orig.tar.xz: ckeditor-dev-4.10.0/plugins/link/lang/et.js <==
﻿/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'et', {
	acccessKey: 'Juurdepääsu võti',
	advanced: 'Täpsemalt',
	advisoryContentType: 'Juhendava sisu tüüp',
	advisoryTitle: 'Juhendav tiitel',
	anchor: {
		toolbar: 'Ankru sisestamine/muutmine',
		menu: 'Ankru omadused',
		title: 'Ankru omadused',
		name: 'Ankru nimi',
		errorName: 'Palun sisesta ankru nimi',
		remove: 'Eemalda ankur'
	},
	anchorId: 'Elemendi id järgi',
	anchorName: 'Ankru nime järgi',
	charset: 'Lingitud ressursi märgistik',
	cssClasses: 'Stiilistiku klassid',
	download: 'Sunni allalaadimine',
	displayText: 'Näidatav tekst',
	emailAddress: 'E-posti aadress',
	emailBody: 'Sõnumi tekst',
	emailSubject: 'Sõnumi teema',
	id: 'ID',
	info: 'Lingi info',
	langCode: 'Keele suund',
	langDir: 'Keele suund',
	langDirLTR: 'Vasakult paremale (LTR)',
	langDirRTL: 'Paremalt vasakule (RTL)',
	menu: 'Muuda linki',
	name: 'Nimi',
	noAnchors: '(Selles dokumendis pole ankruid)',
	noEmail: 'Palun kirjuta e-posti aadress',
	noUrl: 'Palun kirjuta lingi URL',
	other: '<muu>',
	popupDependent: 'Sõltuv (Netscape)',
	popupFeatures: 'Hüpikakna omadused',
	popupFullScreen: 'Täisekraan (IE)',
	popupLeft: 'Vasak asukoht',
	popupLocationBar: 'Aadressiriba',
	popupMenuBar: 'Menüüriba',
	popupResizable: 'Suurust saab muuta',
	popupScrollBars: 'Kerimisribad',
	popupStatusBar: 'Olekuriba',
	popupToolbar: 'Tööriistariba',
	popupTop: 'Ülemine asukoht',
	rel: 'Suhe',
	selectAnchor: 'Vali ankur',
	styles: 'Laad',
	tabIndex: 'Tab indeks',
	target: 'Sihtkoht',
	targetFrame: '<raam>',
	targetFrameName: 'Sihtmärk raami nimi',
	targetPopup: '<hüpikaken>',
	targetPopupName: 'Hüpikakna nimi',
	title: 'Link',
	toAnchor: 'Ankur sellel lehel',
	toEmail: 'E-post',
	toUrl: 'URL',
	toolbar: 'Lingi lisamine/muutmine',
	type: 'Lingi liik',
	unlink: 'Lingi eemaldamine',
	upload: 'Lae üles'
} );

==> ckeditor_4.11.1+dfsg.orig.tar.xz: ckeditor-dev-4.11.1/plugins/link/lang/et.js <==
﻿/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'et', {
	acccessKey: 'Juurdepääsu võti',
	advanced: 'Täpsemalt',
	advisoryContentType: 'Juhendava sisu tüüp',
	advisoryTitle: 'Juhendav tiitel',
	anchor: {
		toolbar: 'Ankru sisestamine/muutmine',
		menu: 'Ankru omadused',
		title: 'Ankru omadused',
		name: 'Ankru nimi',
		errorName: 'Palun sisesta ankru nimi',
		remove: 'Eemalda ankur'
	},
	anchorId: 'Elemendi id järgi',
	anchorName: 'Ankru nime järgi',
	charset: 'Lingitud ressursi märgistik',
	cssClasses: 'Stiilistiku klassid',
	download: 'Sunni allalaadimine',
	displayText: 'Näidatav tekst',
	emailAddress: 'E-posti aadress',
	emailBody: 'Sõnumi tekst',
	emailSubject: 'Sõnumi teema',
	id: 'ID',
	info: 'Lingi info',
	langCode: 'Keele suund',
	langDir: 'Keele suund',
	langDirLTR: 'Vasakult paremale (LTR)',
	langDirRTL: 'Paremalt vasakule (RTL)',
	menu: 'Muuda linki',
	name: 'Nimi',
	noAnchors: '(Selles dokumendis pole ankruid)',
	noEmail: 'Palun kirjuta e-posti aadress',
	noUrl: 'Palun kirjuta lingi URL',
	noTel: 'Please type the phone number', // MISSING
	other: '<muu>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Sõltuv (Netscape)',
	popupFeatures: 'Hüpikakna omadused',
	popupFullScreen: 'Täisekraan (IE)',
	popupLeft: 'Vasak asukoht',
	popupLocationBar: 'Aadressiriba',
	popupMenuBar: 'Menüüriba',
	popupResizable: 'Suurust saab muuta',
	popupScrollBars: 'Kerimisribad',
	popupStatusBar: 'Olekuriba',
	popupToolbar: 'Tööriistariba',
	popupTop: 'Ülemine asukoht',
	rel: 'Suhe',
	selectAnchor: 'Vali ankur',
	styles: 'Laad',
	tabIndex: 'Tab indeks',
	target: 'Sihtkoht',
	targetFrame: '<raam>',
	targetFrameName: 'Sihtmärk raami nimi',
	targetPopup: '<hüpikaken>',
	targetPopupName: 'Hüpikakna nimi',
	title: 'Link',
	toAnchor: 'Ankur sellel lehel',
	toEmail: 'E-post',
	toUrl: 'URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'Lingi lisamine/muutmine',
	type: 'Lingi liik',
	unlink: 'Lingi eemaldamine',
	upload: 'Lae üles'
} );
